summaryrefslogtreecommitdiffstats
path: root/konversation/src/viewcontainer.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:59 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:59 -0600
commit553b2c7f80b5a102ede8e0e3f84f32c057b41781 (patch)
treea3b71bc4ed572767dd22d9f2caaa039e625df149 /konversation/src/viewcontainer.cpp
parentd458ffeadb4dbf9c84ec2f909d901208d443c349 (diff)
downloadkonversation-553b2c7f80b5a102ede8e0e3f84f32c057b41781.tar.gz
konversation-553b2c7f80b5a102ede8e0e3f84f32c057b41781.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit d458ffeadb4dbf9c84ec2f909d901208d443c349.
Diffstat (limited to 'konversation/src/viewcontainer.cpp')
-rw-r--r--konversation/src/viewcontainer.cpp64
1 files changed, 32 insertions, 32 deletions
diff --git a/konversation/src/viewcontainer.cpp b/konversation/src/viewcontainer.cpp
index cbb0ba6..89be010 100644
--- a/konversation/src/viewcontainer.cpp
+++ b/konversation/src/viewcontainer.cpp
@@ -157,7 +157,7 @@ void ViewContainer::setupTabWidget()
KPushButton* closeBtn = new KPushButton(m_tabWidget);
closeBtn->setPixmap(KGlobal::iconLoader()->loadIcon("tab_remove", KIcon::Small));
closeBtn->resize(22, 22);
- closeBtn->setSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed);
+ closeBtn->tqsetSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed);
m_tabWidget->setCornerWidget(closeBtn);
connect(closeBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(closeCurrentView()));
@@ -220,7 +220,7 @@ void ViewContainer::setupViewTree()
{
ChatWindow* view = static_cast<ChatWindow*>(m_tabWidget->page(i));
- if (view->getType() == ChatWindow::Status)
+ if (view->getType() == ChatWindow::tqStatus)
{
if (view == m_frontView)
m_viewTree->addView(view->getName(), view, m_tabWidget->tabIconSet(view), true);
@@ -233,7 +233,7 @@ void ViewContainer::setupViewTree()
{
ChatWindow* view = static_cast<ChatWindow*>(m_tabWidget->page(i));
- if (!view->getType() == ChatWindow::Status)
+ if (!view->getType() == ChatWindow::tqStatus)
{
if (view == m_frontView)
m_viewTree->addView(view->getName(), view, m_tabWidget->tabIconSet(view), true);
@@ -426,7 +426,7 @@ void ViewContainer::updateViewActions(int index)
if (action) action->setEnabled(index < (m_tabWidget->count() - 1));
}
- if (server && (viewType == ChatWindow::Status || server == m_frontServer))
+ if (server && (viewType == ChatWindow::tqStatus || server == m_frontServer))
{
action = actionCollection()->action("reconnect_server");
if (action) action->setEnabled(true);
@@ -457,7 +457,7 @@ void ViewContainer::updateViewActions(int index)
if (notifyAction)
{
notifyAction->setEnabled(viewType == ChatWindow::Channel || viewType == ChatWindow::Query ||
- viewType == ChatWindow::Status || viewType == ChatWindow::Konsole ||
+ viewType == ChatWindow::tqStatus || viewType == ChatWindow::Konsole ||
viewType == ChatWindow::DccTransferPanel || viewType == ChatWindow::RawLog);
notifyAction->setChecked(view->notificationsEnabled());
}
@@ -542,7 +542,7 @@ void ViewContainer::updateViewActions(int index)
name = name.replace('&', "&&");
channelListAction->setEnabled(true);
channelListAction->setChecked(m_frontServer->getChannelListPanel());
- channelListAction->setText(i18n("Channel &List for %1").arg(name));
+ channelListAction->setText(i18n("Channel &List for %1").tqarg(name));
}
else
{
@@ -562,7 +562,7 @@ void ViewContainer::updateViewActions(int index)
{
TQString name = view->getName();
name = name.replace('&', "&&");
- action->setText(i18n("&Open Logfile for %1").arg(name));
+ action->setText(i18n("&Open Logfile for %1").tqarg(name));
}
}
@@ -573,7 +573,7 @@ void ViewContainer::updateViewActions(int index)
if (action && view->getType() == ChatWindow::Channel)
{
action->setEnabled(true);
- action->setText(i18n("&Channel Settings for %1...").arg(view->getName()));
+ action->setText(i18n("&Channel Settings for %1...").tqarg(view->getName()));
}
else if (action)
{
@@ -702,7 +702,7 @@ void ViewContainer::updateFrontView()
{
case ChatWindow::Channel:
case ChatWindow::Query:
- case ChatWindow::Status:
+ case ChatWindow::tqStatus:
case ChatWindow::ChannelList:
case ChatWindow::RawLog:
emit setStatusBarLagLabelShown(true);
@@ -729,7 +729,7 @@ void ViewContainer::updateViews(const Konversation::ServerGroupSettings* serverG
if (serverGroup)
{
- if (view->getType() == ChatWindow::Status && view->getServer()->getServerGroup() == serverGroup)
+ if (view->getType() == ChatWindow::tqStatus && view->getServer()->getServerGroup() == serverGroup)
{
TQString label = view->getServer()->getDisplayName();
@@ -762,7 +762,7 @@ void ViewContainer::updateViews(const Konversation::ServerGroupSettings* serverG
if (!Preferences::tabNotificationsText())
- m_viewTree->setViewColor(view, m_window->colorGroup().foreground());
+ m_viewTree->setViewColor(view, m_window->tqcolorGroup().foreground());
}
else if (m_tabWidget)
{
@@ -773,7 +773,7 @@ void ViewContainer::updateViews(const Konversation::ServerGroupSettings* serverG
m_tabWidget->setTabIconSet(view, images->getCloseIcon());
if (!Preferences::tabNotificationsText())
- m_tabWidget->setTabColor(view, m_window->colorGroup().foreground());
+ m_tabWidget->setTabColor(view, m_window->tqcolorGroup().foreground());
}
if (Preferences::tabNotificationsLeds() || Preferences::tabNotificationsText())
@@ -1040,7 +1040,7 @@ void ViewContainer::unsetViewNotification(ChatWindow* view)
m_viewTree->setViewIcon(view, images->getPrivateLed(false));
break;
- case ChatWindow::Status:
+ case ChatWindow::tqStatus:
m_viewTree->setViewIcon(view, images->getServerLed(false));
break;
@@ -1051,19 +1051,19 @@ void ViewContainer::unsetViewNotification(ChatWindow* view)
}
TQColor textColor = (Preferences::inputFieldsBackgroundColor()
- ? Preferences::color(Preferences::ChannelMessage) : m_window->colorGroup().foreground());
+ ? Preferences::color(Preferences::ChannelMessage) : m_window->tqcolorGroup().foreground());
if (view->getType() == ChatWindow::Channel)
{
Channel *channel = static_cast<Channel*>(view);
if (!channel->joined())
- textColor = KonversationApplication::instance()->palette(m_viewTree).disabled().text();
+ textColor = KonversationApplication::instance()->tqpalette(m_viewTree).disabled().text();
}
else if (view->getType() == ChatWindow::Query)
{
if (!view->getServer()->isConnected())
- textColor = KonversationApplication::instance()->palette(m_tabWidget).disabled().text();
+ textColor = KonversationApplication::instance()->tqpalette(m_tabWidget).disabled().text();
}
m_viewTree->setViewColor(view, textColor);
@@ -1083,7 +1083,7 @@ void ViewContainer::unsetViewNotification(ChatWindow* view)
m_tabWidget->setTabIconSet(view, images->getPrivateLed(false));
break;
- case ChatWindow::Status:
+ case ChatWindow::tqStatus:
m_tabWidget->setTabIconSet(view, images->getServerLed(false));
break;
@@ -1093,19 +1093,19 @@ void ViewContainer::unsetViewNotification(ChatWindow* view)
}
}
- TQColor textColor = m_window->colorGroup().foreground();
+ TQColor textColor = m_window->tqcolorGroup().foreground();
if (view->getType() == ChatWindow::Channel)
{
Channel *channel = static_cast<Channel*>(view);
if (!channel->joined())
- textColor = KonversationApplication::instance()->palette(m_tabWidget).disabled().text();
+ textColor = KonversationApplication::instance()->tqpalette(m_tabWidget).disabled().text();
}
else if (view->getType() == ChatWindow::Query)
{
if (!view->getServer()->isConnected())
- textColor = KonversationApplication::instance()->palette(m_tabWidget).disabled().text();
+ textColor = KonversationApplication::instance()->tqpalette(m_tabWidget).disabled().text();
}
m_tabWidget->setTabColor(view, textColor);
@@ -1196,7 +1196,7 @@ void ViewContainer::addView(ChatWindow* view, const TQString& label, bool weinit
{
tmp_ChatWindow = static_cast<ChatWindow *>(m_tabWidget->page(sindex));
- if (tmp_ChatWindow->getType() == ChatWindow::Status && tmp_ChatWindow->getServer() == view->getServer())
+ if (tmp_ChatWindow->getType() == ChatWindow::tqStatus && tmp_ChatWindow->getServer() == view->getServer())
{
for (int index = sindex + 1; index < m_tabWidget->count(); index++)
{
@@ -1226,7 +1226,7 @@ void ViewContainer::addView(ChatWindow* view, const TQString& label, bool weinit
{
tmp_ChatWindow = static_cast<ChatWindow *>(m_tabWidget->page(sindex));
- if (tmp_ChatWindow->getType() == ChatWindow::Status && tmp_ChatWindow->getServer() == view->getServer())
+ if (tmp_ChatWindow->getType() == ChatWindow::tqStatus && tmp_ChatWindow->getServer() == view->getServer())
{
placement = sindex + 1;
break;
@@ -1245,7 +1245,7 @@ void ViewContainer::addView(ChatWindow* view, const TQString& label, bool weinit
{
tmp_ChatWindow = static_cast<ChatWindow *>(m_tabWidget->page(sindex));
- if (tmp_ChatWindow->getType() == ChatWindow::Status && tmp_ChatWindow->getServer() == view->getServer())
+ if (tmp_ChatWindow->getType() == ChatWindow::tqStatus && tmp_ChatWindow->getServer() == view->getServer())
{
for (int index = sindex + 1; index < m_tabWidget->count(); index++)
{
@@ -1276,7 +1276,7 @@ void ViewContainer::addView(ChatWindow* view, const TQString& label, bool weinit
tmp_ChatWindow = static_cast<ChatWindow*>(m_tabWidget->page(sindex));
wtype = tmp_ChatWindow->getType();
- if (wtype != ChatWindow::Status && wtype != ChatWindow::Channel
+ if (wtype != ChatWindow::tqStatus && wtype != ChatWindow::Channel
&& wtype != ChatWindow::RawLog && wtype != ChatWindow::Query
&& wtype != ChatWindow::DccChat && wtype != ChatWindow::ChannelList)
{
@@ -1286,7 +1286,7 @@ void ViewContainer::addView(ChatWindow* view, const TQString& label, bool weinit
}
break;
- case ChatWindow::Status:
+ case ChatWindow::tqStatus:
if (Preferences::tabNotificationsLeds())
iconSet = images->getServerLed(false);
else if (Preferences::closeButtons())
@@ -1299,7 +1299,7 @@ void ViewContainer::addView(ChatWindow* view, const TQString& label, bool weinit
tmp_ChatWindow = static_cast<ChatWindow *>(m_tabWidget->page(sindex));
if (tmp_ChatWindow->getType() != ChatWindow::Channel
- && tmp_ChatWindow->getType() != ChatWindow::Status
+ && tmp_ChatWindow->getType() != ChatWindow::tqStatus
&& tmp_ChatWindow->getType() != ChatWindow::RawLog
&& tmp_ChatWindow->getType() != ChatWindow::Query
&& tmp_ChatWindow->getType() != ChatWindow::DccChat)
@@ -1624,14 +1624,14 @@ void ViewContainer::updateViewEncoding(ChatWindow* view)
if (codecAction)
{
- if(viewType == ChatWindow::Channel || viewType == ChatWindow::Query || viewType == ChatWindow::Status)
+ if(viewType == ChatWindow::Channel || viewType == ChatWindow::Query || viewType == ChatWindow::tqStatus)
{
codecAction->setEnabled(view->isChannelEncodingSupported());
TQString encoding = view->getChannelEncoding();
if(m_frontServer)
{
- codecAction->changeItem(0, i18n("Default encoding", "Default ( %1 )").arg(m_frontServer->getIdentity()->getCodecName()));
+ codecAction->changeItem(0, i18n("Default encoding", "Default ( %1 )").tqarg(m_frontServer->getIdentity()->getCodecName()));
}
if(encoding.isEmpty())
@@ -1682,7 +1682,7 @@ void ViewContainer::showViewContextMenu(TQWidget* tab, const TQPoint& pos)
}
}
- if (viewType == ChatWindow::Status)
+ if (viewType == ChatWindow::tqStatus)
{
TQPtrList<KAction> serverActions;
KAction* action = actionCollection()->action("disconnect_server");
@@ -1825,7 +1825,7 @@ void ViewContainer::appendToFrontmost(const TQString& type,const TQString& messa
}
// This might happen if canBeFrontView() is false for active ChatWindow
// and the view does not belong to any server (e.g. DCC Status View).
// Discard message in this case.
if (!serverView) return;
@@ -1957,7 +1957,7 @@ void ViewContainer::openLogFile()
ChatWindow* view=static_cast<ChatWindow*>(m_frontView);
ChatWindow::WindowType viewType=view->getType();
if (viewType==ChatWindow::Channel || viewType==ChatWindow::Query ||
- viewType==ChatWindow::Status || viewType==ChatWindow::DccChat)
+ viewType==ChatWindow::tqStatus || viewType==ChatWindow::DccChat)
{
openLogFile(view->getName(), view->logFileName());
}
@@ -1969,7 +1969,7 @@ void ViewContainer::openLogFile(const TQString& caption, const TQString& file)
if (!file.isEmpty())
{
LogfileReader* logReader = new LogfileReader(m_tabWidget, file);
- addView(logReader, i18n("Logfile of %1").arg(caption));
+ addView(logReader, i18n("Logfile of %1").tqarg(caption));
logReader->setServer(0);
}
}
@@ -1825,7 +1825,7 @@ void ViewContainer::appendToFrontmost(const TQString& type,const TQString& messa
}
// This might happen if canBeFrontView() is false for active ChatWindow
- // and the view does not belong to any server (e.g. DCC Status View).
+ // and the view does not belong to any server (e.g. DCC tqStatus View).
// Discard message in this case.
if (!serverView) return;